==> 3.0.2.056.tar.gz: ordermanager/docs/daux/editions/010_Editionen.md <==
---
title: Editionen
---

Das Modul **{$modulename}** erhalten Sie in verschiedenen Editionen mit unterschiedlichem Funktionsumfang. Hierbei unterscheiden sich ausschließlich die verwendbaren Filter und Aktionen zwischen den Editionen. Die grundsätzliche Modulfunktion ist immer gleich.

Anzahl möglicher Aufgaben:

| Free-Edition	| Standard-Edition	| Premium-Edition	|
|:-------------:|:-----------------:|:-----------------:|
| 5				| 25				| beliebig			|

Bedingungen:

| Bedingungen										| Free-Edition	| Standard-Edition	| Premium-Edition	|
|---------------------------------------------------|:-------------:|:-----------------:|:-----------------:|
| ab (inklusive) Bestellnummer						| X				| X					| X					|
| bis (inklusive) Bestellnummer						| X				| X					| X					|
| Zeitraum (1)										| X				| X					| X					|
| Zeitraum (2)										| X				| X					| X					|
| nicht gesetztes...								| X				| X					| X					|
| aus diesen Wochentagen							| X				| X					| X					|
| bei diesen Zahlarten								| X				| X					| X					|
| bei diesen Versandarten							| X				| X					| X					|
| bei gesetztem Trackingcode						| X				| X					| X					|
| bei stornierter Bestellung						| X				| X					| X					|
| bei nicht stornierter Bestellung					| X				| X					| X					|
| bei stornierten Artikeln innerhalb der Bestellung	| X				| X					| X					|
| Bestellsumme										| X				| X					| X					|
| hat Rechnungsnummer erhalten						| X				| X					| X					|
| Transaktionsstatus								| X				| X					| X					|
| bei verwendeter Währung							| X				| X					| X					|
| bei verwendeter Sprache							| X				| X					| X					|
| in einem der Ordner								| X				| X					| X					|
| nicht in einem der Ordner							| X				| X					| X					|
| enthält selektierte Artikel (1)					| X				| X					| X					|
| enthält selektierte Artikel (2)					| X				| X					| X					|
| enthält nicht selektierte Artikel (1)				| X				| X					| X					|
| enthält nicht selektierte Artikel (2)				| X				| X					| X					|
| Suchmuster zur Filterung der Mailadresse			| X				| X					| X					|
| Liefer- bzw. Rechnungsadresse aus Land			| X				| X					| X					|
| Kunde ist in Gruppe								| X				| X					| X					|
| Kunde ist nicht in Gruppe							| X				| X					| X					|
| Methode des Auftragslistenobjekts ausführen		|				|					| X					|
| Bestellungsfeld auf Wert prüfen					|				|					| X					|
| andere Aufgabe									|				|					| X					|

Aufgaben:

| Aufgaben										| Free-Edition	| Standard-Edition	| Premium-Edition	|
|-----------------------------------------------|:-------------:|:-----------------:|:-----------------:|
| E-Mail senden									| X				| X					| X					|
| Aufträge in Ordner verschieben				| X				| X					| X					|
| Aufträge stornieren							|				| X					| X					|
| Versendet-am Datum setzen						|				| X					| X					|
| Bezahlt-am Datum setzen						|				| X					| X					|
| Versandkosten ändern							|				| X					| X					|
| Rabatte ändern								|				| X					| X					|
| PDF generieren								|				| X					| X					|
| Feld mit Wert füllen							|				| 					| X					|
| Kundengruppe zuordnen / entfernen				|				| X					| X					|
| Export in Liste								|				| X					| X					|
| Individualaktionen / -bedingungen definieren	|				| 					| X					|

==> 4.0.0.0.tar.gz: ordermanager/docs/daux/editions/010_Editionen.md <==
---
title: Editionen
---

Das Modul **{$modulename}** erhalten Sie in verschiedenen Editionen mit unterschiedlichem Funktionsumfang. Die hier nicht genannten Modulfunktionen sind in allen Editionen gleich.

## Funktionsumfang

|                                   | Free-Edition	| Standard-Edition	| Premium-Edition	|
|-----------------------------------|:-------------:|:-----------------:|:-----------------:|
| Anzahl möglicher Aufgaben         | 5				| 25				| beliebig			|
| vor-Ausführung-Script möglich     |               |                   | X                 |
| nach-Ausführung-Script möglich    |               |                   | X                 |

## Aufgabenauslöser

|                                               | Free-Edition  | Standard-Edition  | Premium-Edition   |
|-----------------------------------------------|:-------------:|:-----------------:|:-----------------:|
| periodischer Start per Cronjob                | X             | X                 | X                 |
| manueller Start direkt an den Bestellungen    | X             | X                 | X                 |
| beim Bestellabschluss durch den Kunden        |               | X                 | X                 |
| beim Speichern der Bestellung                 |               | X                 | X                 |

## Bedingungen

|           										| Free-Edition	| Standard-Edition	| Premium-Edition	|
|---------------------------------------------------|:-------------:|:-----------------:|:-----------------:|
| ab (inklusive) Bestellnummer						| X				| X					| X					|
| bis (inklusive) Bestellnummer						| X				| X					| X					|
| Zeitraum (1)										| X				| X					| X					|
| Zeitraum (2)										| X				| X					| X					|
| nicht gesetztes...								| X				| X					| X					|
| aus diesen Wochentagen							| X				| X					| X					|
| bei diesen Zahlarten								| X				| X					| X					|
| bei diesen Versandarten							| X				| X					| X					|
| bei gesetztem Trackingcode						| X				| X					| X					|
| bei stornierter Bestellung						| X				| X					| X					|
| bei nicht stornierter Bestellung					| X				| X					| X					|
| bei stornierten Artikeln innerhalb der Bestellung	| X				| X					| X					|
| Bestellsumme										| X				| X					| X					|
| hat Rechnungsnummer erhalten						| X				| X					| X					|
| Transaktionsstatus								| X				| X					| X					|
| bei verwendeter Währung							| X				| X					| X					|
| bei verwendeter Sprache							| X				| X					| X					|
| in einem der Ordner								| X				| X					| X					|
| nicht in einem der Ordner							| X				| X					| X					|
| enthält selektierte Artikel (1)					| X				| X					| X					|
| enthält selektierte Artikel (2)					| X				| X					| X					|
| enthält nicht selektierte Artikel (1)				| X				| X					| X					|
| enthält nicht selektierte Artikel (2)				| X				| X					| X					|
| Suchmuster zur Filterung der Mailadresse			| X				| X					| X					|
| Liefer- bzw. Rechnungsadresse aus Land			| X				| X					| X					|
| Kunde ist in Gruppe								| X				| X					| X					|
| Kunde ist nicht in Gruppe							| X				| X					| X					|
| Methode des Auftragslistenobjekts ausführen		|				|					| X					|
| Bestellungsfeld auf Wert prüfen					|				|					| X					|
| andere Aufgabe									|				|					| X					|

## Aktionen

|       										| Free-Edition	| Standard-Edition	| Premium-Edition	|
|-----------------------------------------------|:-------------:|:-----------------:|:-----------------:|
| E-Mail senden									| X				| X					| X					|
| Aufträge in Ordner verschieben				| X				| X					| X					|
| Aufträge stornieren							|				| X					| X					|
| Versendet-am Datum setzen						|				| X					| X					|
| Bezahlt-am Datum setzen						|				| X					| X					|
| Versandkosten ändern							|				| X					| X					|
| Rabatte ändern								|				| X					| X					|
| PDF generieren								|				| X					| X					|
| Feld mit Wert füllen							|				| 					| X					|
| Kundengruppe zuordnen / entfernen				|				| X					| X					|
| Export in Liste								|				| X					| X					|
| Individualaktionen / -bedingungen definieren	|				| 					| X					|
